# Perforce Helix Installer

## Welcome 

Welcome to the home of the Perforce Helix Installer project.

Perforce [Helix](http://www.perforce.com/helix) is a unified platform for collaborative development, version management, and protection of intellectual property.  It consists of an integrated ecosystem of proven, enterprise-grade systems for versioning, collaboration and code review, continuous integration and delivery, and other aspects of a DevOps pipeline.

This **Helix Installer** is capable of quickly transforming a vanilla Linux machine -- virtual, bare metal, Docker container, etc. -- into a near-enterprise-grade deployment of several Helix Core Server components typically be present in a true enterprise installation.

## Relationship to Server Deployment Package (SDP)

The installation uses the [Server Deployment Package (SDP)](https://swarm.workshop.perforce.com/projects/perforce-software-sdp).

By default, the Helix Installer installs a specific version of the SDP, using a simple tar file from the downloads folder of the SDP project.  This version is coded in a Helix Installer script, which is updated and release from time to time following successful integration testing with the given SDP version.

The Helix Installer can also clone the SDP project's ```main``` or ```dev``` branch to get the latest software available in the given branch.  This is done using Helix native DVCS features (e.g. ```p4 clone```) to clone the SDP mainline from the workshop, optionally overlaying the latest with a specified shelved changelist (see SDP Dev Branch Testing below).

## Helix Installer Installation Cases
The installation is suitable for:

* Test suites for Helix server trigger and broker filter scripts deployed in enterprise environments.  For example, the [CBD](https://swarm.workshop.perforce.com/projects/perforce-software-cbd) test suite uses the Helix Installer to quickly spin up a test environment for server and triggers
* Demonstrations of Helix Core
* Proof of Concept (PoC) Deployments
* Training
* Evaluation and Pilot projects.  Because the Helix Installer uses the SDP, **transition from the demo-grade installation of the Helix Installer to an enterprise-grade installation is straightforward**.
* Testing SDP changes shelved to the dev branch in The Workshop (see SDP Dev Branch Testing below).

The Helix Installer is alternative to the [Helix Enterprise Evaluation virtual appliance (OVA)](http://www.perforce.com/downloads/helix).

Features
---
* **Easy**.  Provides reasonable defaults for port numbers, passwords, data storage areas, and all inputs that would otherwise require human interaction.
* **Comprehensive**.  Installs P4D and P4Broker, SDP, and a complete development pre-configured environment include Perl, P4Perl, Python, and P4Python, with appropriate shell environment settings to use them all immediately.  And more to come --  future versions may include Helix Swarm, Jenkins, etc.
* **Fast**.  Runs in under 25 minutes, including download time and building required dependencies, including Python and Perl.  **Runs in about 2 minutes '-fast' option**, which excludes the optional Perl and Python builds.
* **Simplifies Enterprise Deployment**.  While optimized for getting going quickly, the Helix Installer is designed to enable a fast path from a Proof of Concept (PoC) to small-scale production deployment following the Helix evaluation, with only a nominal hop from there to a large-scale global enterprise deployment (which requires custom configuration based on the specific global topology).
* Automates connection to the [Perforce Package Repository](http://package.perforce.com/).
* Pre-loads the [Perforce Sample Depot](http://answers.perforce.com/articles/KB/2439), making it instantly ready for training and evaluation purposes.

### Instructions and Usage Example

The `reset_sdp.sh` script is the only script that should be downloaded.  It downloads everything it needs, including other scripts and files from this Helix Installer package, executables from the Perforce FTP site, and the SDP from The Workshop (acquired by cloning).

Once installing a vanilla RHEL/CentOS 6.9 (or similar) machine, do this as root:

    useradd perforce
    mkdir -p /hxdepots/reset
    chown -R perforce:perforce /hxdepots/reset
    cd /hxdepots/reset
    curl -k -s -O https://swarm.workshop.perforce.com/downloads/guest/perforce_software/helix-installer/main/src/reset_sdp.sh

    chmod +x reset_sdp.sh

    ./reset_sdp.sh -man

    ./reset_sdp.sh 2>&1 | tee reset_sdp.log

A similar procedure works for Mac OSX, except that the standard Mac interface is used for creating the `perforce` user account rather than the `useradd` command, and the `chown` command may need to specify a different group (e.g. `staff`), depending on the Mac OSX environment.

### SDP Dev Branch Testing

The Helix Installer can be used to test SDP changes shelved totthe SDP dev branch in The Workshop.  The following example illustrates testing a change in shelved changelist 23123:

    su -
    useradd perforce
    mkdir -p /hxdepots/reset
    chown -R perforce:perforce /hxdepots/reset
    cd /hxdepots/reset
    curl -k -s -O https://swarm.workshop.perforce.com/downloads/guest/perforce_software/helix-installer/main/src/reset_sdp.sh

    ./reset_sdp.sh -b dev,@23123 2>&1 | tee reset_sdp.CL23123.log

After the first test, an iterative test cycle may follow on the same shelved changelist. For each test iteration, the shelved changelist is first updated in the workspace from which the change was originally shelved, e.g. with a command like ```p4 shelve -f -c 23123```.

Then a new test can be done by calling reset_sdp.sh with the same arguments. The script will re-install the SDP cleanly, and then re-apply the updated shelved changelist.

## Helix Installer Release Notes

See the [Helix Installer Release Notes](https://swarm.workshop.perforce.com/projects/perforce_software-helix-installer/files/main/doc/ReleaseNotes.md).

## Helix Installer Roadmap

### Helix Installer 2017.4 (available now)

Helix Installer 2017.4 is available today, and installs the following Helix Components, all fully configured an integrated:

* **P4D** 2017.2 - the Helix Versioning Engine, the core of Helix (with or without SSL enabled).
* **P4Broker** 2017.2 - the Helix Broker, enhances custom automation capabilities, simplifies maintenances.
* **SDP** 2017.3 - Server Deployment Package (For managing the SDP).
* **Sample Depot** data set for training, evaluation, and demo, and pilot projects.

### Helix Installer 2018.1 (ETA Q2 2018)

The 2018.1 release is expected to add support for:

* Helix Swarm - Collaborative web-based code review and continuous delivery.

## Platform Support

Helix Installer 2017.3 supports: 

* CentOS/RHEL 6.5 thru 7.3.
* Limited support for Ubuntu (not presently tested).
* Limited support for Mac OSX/Darwin

Future releases may add support for other popular Linux distributions, including those using APT, e.g. Ubuntu.  It may well work as-is presently on other YUM-based installations

## Project Status

As of November 2017, this project is functional and has been actively used since April 2015.  It has been actively maintained to keep pace with SDP changes.  However, planned releases to add new features, auto-installing Swarm and Git Fusion support, have been deferred.

## Safety Warning
Note that this software ***SHOULD NEVER EXIST*** on a Production Perforce server.  The is intended to quickly tear down and rebuild a fresh Perforce server (e.g. for operating test suites).  It should not exist on a machine containing real Perforce data.

It may be useful for doing an initial installation, e.g. to a cloud hosted environment.  After the initial install, the reset_sdp.sh script should be removed.

## Case Studies

### Case Study: Sample Usage of Helix Installer in CBD Test Suite

The [Component Based Development (CBD)](https://swarm.workshop.perforce.com/projects/perforce-software-cbd) system, another project in The Workshop, uses this Helix Installer as part of its automated test suite.  In conjunction with Vagrant and Virtual Box, which build a vanilla VM from the ground up, the [CBD Test Suite](https://swarm.workshop.perforce.com/projects/perforce-software-cbd/files/main/test/auto_test_cbd_vagrant.sh) uses the Helix Installer to deploy a Perforce server, complete with Sample Depot test data set, plus Python and P4Python needed to test the CBD scripts.

### Case Study: Sample Usage of Helix Installer in Battle School Workshop

A slightly modified Helix Installer is a key component of the Battle School Workshop.  The Battle School Workshop Lab Engine quickly tears down and spins up a fresh, enterprise-style Helix installation -- and then breaks it in order to simulate real-world problems that students learn to identify and fix.  The Battle School version of the Helix Installer (not presently available for public consumption) uses a simulated global topology with replicas and edge servers.

## Contact Us

Please [contact Perforce Consulting Services] (mailto:consulting@perforce.com) for more information.


